/*
* newUploadImage(parameter, successCallback, errorCallback)  上传图片
* parameter[object]	parameter.wechatURL 微信上传时候的请求地址
* 					parameter.appURL	  app图片上传服务器的位置
* successCallback(serverUrl)	成功时候的回调函数serverUrl图片上传之后再服务器的地址
* errorCallback		失败时候的回调函数
* */
// 上传图片
function newUploadImage(parameter, successCallback, errorCallback){
    if(isWechatClient()){
        wx.chooseImage({
            count: 1,
            success: function(res) {
                var fileUrl = res.localIds[0];
                wechatUploadImage_common(fileUrl);
            }
        });
    }else{
        appUploadImage_actionsheet();
    }

	// 微信上传
	function wechatUploadImage_common(fileUrl){
		J.showToast('微信中上传图片');
	    wx.uploadImage({
	        localId: fileUrl,
	        success: function(res) {
				var serverId = res.serverId;
				
	            wechatUploadImage_service(serverId, fileUrl);
	        },
	        fail: function(res) {
	            J.showToast('获取本地图片失败');
	            errorCallback();
	        }
	    });
	}
	
	// ==============wechat保存图片
	function wechatUploadImage_service(serverId, fileUrl) {

		// 服务器地址
	    var url = parameter.wechatURL;
	    var par = {
	        openId : J.Cache.get('openId').data,
	        mediaId : serverId 
	    };

	    service.get(url,par,function(data){

	    	if(data === '' || data == null || typeof(data) == 'undefined' ){
	        	J.showToast("上传失败");
	        	errorCallback();
	        }else {
	        	J.showToast("上传成功");

	        	successCallback(data, fileUrl);
	        }
	    })
	}
	
	// app选择获取图片方式
	function appUploadImage_actionsheet() {
		//图片来源
		pictureSource = navigator.camera.PictureSourceType;
		destinationType = navigator.camera.DestinationType;
	
		J.Popup.actionsheet([{
				text: '拍照',
				handler: function() {
					app_capturePhotoEdit()
				}
			},
			{
				text: '从照片中选择',
				handler: function() {
					app_getPhoto(pictureSource.PHOTOLIBRARY)
				}
			}
		]);
	}
	
	//	使用设备上的摄像头拍照，并获得Base64编码字符串格式的图像
	function app_capturePhoto() {
		// Take picture using device camera and retrieve image as base64-encoded string
		navigator.camera.getPicture(app_UploadImg, app_onFail, {
			quality: 10,
			destinationType: destinationType.DATA_URL
		});
	}
	//	使用设备上的摄像头拍照，并获得Base64编码字符串格式的可编辑图像  
	function app_capturePhotoEdit() {
		// Take picture using device camera, allow edit, and retrieve image as base64-encoded string
		navigator.camera.getPicture(app_UploadImg, app_onFail, {
			quality: 20,
			allowEdit: true,
			destinationType: destinationType.DATA_URL
		});
	}
	// 从图片库选取照片
	function app_getPhoto(source) {
		// Retrieve image file location from specified source
		navigator.camera.getPicture(app_UploadImg, app_onFail, {
			quality: 0.2,
			allowEdit: true,
			destinationType: destinationType.DATA_URL,
			sourceType: source
		});
	}
	// 调用相机或者相册获取url失败
	function app_onFail(message) {

		J.showToast("获取本地图片失败");
	}
	
	// 上传图片   调取相机或者相册获取url成功之后的回调函数
	function app_UploadImg(imageData) {
		var base64Data = 'data:image/jpeg;base64,' + imageData;

		// 获取到base64;
		console.log('图片:', base64Data);
		$.ajax({
			type: "post",
			url: serverUrl + "/B64Upload?fileFolder=headPhoto",
			data: {"imageData": base64Data},
			dataType:"json",
			success: function(data) {
				// var res = JSON.parse(data);
				console.log('上传返回res:', data);
				if (data.success) {
					// saveHeadPhoto_service(data.fileUrl);
					J.showToast('上传成功');
					// successCallback(data.fileUrl);
					successCallback(data.fileUrl, base64Data);
					
				} else {
					J.showToast("上传失败");
					errorCallback();
				}
			},
			error: function() {
				J.showToast("上传时候失败");
				errorCallback();
			}
		});

		// //上传你成功的回调函数
		// var win = function(r) {

		// 	J.showToast('上传成功');
		// 	var fileUrl = r.response.substr(r.response.indexOf('thumb') - r.response.length);
		// 	successCallback(fileUrl);
		// }
		// //上传失败的回调函数
		// var fail = function(error) {

		// 	J.showToast("上传时候失败");
		// 	errorCallback();
		// }
		// // 可选的参数
		// var options = new FileUploadOptions();
		// options.fileKey = "fileAddPic";
		// options.fileName = fileURL.substr(fileURL.lastIndexOf('/') + 1);
		// options.mimeType = "text/plain";
	
		// //	var serverPhotoUrl = serverUrl + 'AppUpload';
		// var serverPhotoUrl = parameter.appURL;


		
		// var ft = new FileTransfer();
		// // fileURL 设备上文件的url;
		// // encodeURI(serverPhotoUrl); 接收文件的服务器的URL，由编码encodeURI()。
		// ft.upload(fileURL, encodeURI(serverPhotoUrl), win, fail, options);
	}
}
